pub fn detect_compression(bytes: &[u8]) -> CompressionExpand description
Detect compression format from the first bytes of a file.
1f 8b= gzip28 b5 2f fd= zstd- Otherwise = uncompressed
pub fn detect_compression(bytes: &[u8]) -> CompressionDetect compression format from the first bytes of a file.
1f 8b = gzip28 b5 2f fd = zstd