con_frame_iterator_next

Function con_frame_iterator_next 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn con_frame_iterator_next( iterator: *mut CConFrameIterator, ) -> *mut RKRConFrame
Reads the next frame from the iterator, returning an opaque handle. The caller OWNS the returned handle and must free it with free_rkr_frame.