#[repr(C)]pub struct RKRArrayView {
pub data: *const c_void,
pub n: usize,
pub cols: u32,
pub dtype_code: u8,
pub dtype_bits: u8,
}Expand description
A transparent, “lossy” C-struct containing only the core atomic data.
This can be extracted from an RKRConFrame handle for direct data access.
The caller is responsible for freeing the atoms array using free_c_frame.
Borrowed SoA column. data is valid until the parent frame is freed
or a mutating call reallocates storage. No copy.
Fields
data: *const c_voidn: usizecols: u32dtype_code: u8dtype_bits: u8Auto Trait Implementations
impl !Send for RKRArrayView
impl !Sync for RKRArrayView
impl Freeze for RKRArrayView
impl RefUnwindSafe for RKRArrayView
impl Unpin for RKRArrayView
impl UnsafeUnpin for RKRArrayView
impl UnwindSafe for RKRArrayView