pub fn detect_compression(bytes: &[u8]) -> CompressionExpand description
Detect compression format from the first bytes of a file.
1f 8b= gzip- Otherwise = uncompressed
pub fn detect_compression(bytes: &[u8]) -> CompressionDetect compression format from the first bytes of a file.
1f 8b = gzip