A transparent, “lossy” C-struct containing only the core atomic data.
This can be extracted from an RKRConFrame handle for direct data access.
The caller is responsible for freeing the atoms array using free_c_frame.
Creates a new iterator for a .con file.
The caller OWNS the returned pointer and MUST call free_con_frame_iterator.
Returns NULL if there are no more frames or on error.
Copies a header string line into a user-provided buffer.
This is a C style helper… where the user explicitly sets the buffer.
Returns the number of bytes written (excluding null terminator), or -1 on error.